const data = [
  {
    day: 'Mon',
    apricots: 120,
    blueberries: 180,
    cherries: 100,
  },
  {
    day: 'Tue',
    apricots: 60,
    blueberries: 185,
    cherries: 105,
  },
  {
    day: 'Wed',
    apricots: 100,
    blueberries: 215,
    cherries: 110,
  },
  {
    day: 'Thu',
    apricots: 80,
    blueberries: 230,
    cherries: 105,
  },
  {
    day: 'Fri',
    apricots: 120,
    blueberries: 240,
    cherries: 105,
  },
];

const yScale = d3
  .scaleLinear()
  .domain([0, 600])
  .range([200, 0]);

const areaGenerator = d3
  .area()
  .x((d, i) => i * 100)
  .y0(d => yScale(d[0]))
  .y1(d => yScale(d[1]));

const colors = ['#FBB65B', '#513551', '#de3163'];

const stack = d3
  .stack()
  .keys(['apricots', 'blueberries', 'cherries'])
	// .order(d3.stackOrderInsideOut) // NEW
	.offset(d3.stackOffsetExpand); // NEW

const stackedSeries = stack(data);

d3.select('g')
  .selectAll('path')
  .data(stackedSeries)
  .join('path')
  .style('fill', (d, i) => colors[i])
  .attr('d', areaGenerator);

// ---------------------------
// 				  .order()
// ---------------------------
// Order of the stacks can be configured as .order()
// `stack.order(d3.stackOrderNone);`

// e.g :-
// d3.stackOrderNone(Default) -> Series in same order as specified in .keys()
// d3.stackOrderAscending -> 	Smallest series at the bottom
// d3.stackOrderDescending -> Largest series at the bottom
// d3.stackOrderInsideOut -> Largest series in the middle
// d3.stackOrderReverse -> Largest series in the middle

// --------------------------
//				 .offset()
// --------------------------
//By default the stacked series have a baseline of zero. However you can configure the offset of the stack generator to achieve different effects.
// `stack.offset(d3.stackOffsetExpand)`

// e.g :-
// d3.stackOffsetNone(Default) -> No offset
// d3.stackOffsetExpand -> Sum of series is normalised (to a value of 1)
// d3.stackOffsetSilhouette -> Center of stacks is at y=0
// d3.stackOffsetWiggle -> Wiggle of layers is minimised (typically used for streamgraphs)































